What’s new in version 1.1.3
===========================
Version available since July 4th 2022


Bug fixed
---------
- Bug caused by new version of Jax (0.3.14)


New Features
------------
- A new attribute "debug" in Spec class, to print values and gradient at each iteration of the optimization.


Contributors
------------
Lucas Agobert
